@@ -88,7 +88,14 @@ class qaConverter(object):
     
     
     @staticmethod
-    def writeHistoryData(elem,post_id,instanceId,HistoryType,postType,val,name):
+    def writeHistoryData(*args, **kwargs):
+        elem = kwargs['elem']
+        post_id = kwargs['post_id']
+        instanceId = kwargs['instanceId']
+        HistoryType = kwargs['HistoryType']
+        postType = kwargs['postType']
+        val = kwargs['val']
+        name = kwargs['name']
         filePath = name+'/'
         if(val==1 and postType[0]!='2'):
             filePath = filePath+"Post"+str(post_id)+".knolml"
@@ -116,25 +123,7 @@ class qaConverter(object):
                     Timestamp information
                     '''
                 
-                    TimeStamp = t+t+t+"<TimeStamp>\n "
-                    myFile.write(TimeStamp)
-                    if(elem.attrib.get("CreationDate") != None):
-                        CreationDate = t+t+t+t+"<CreationDate>"+elem.attrib['CreationDate']+"</CreationDate> \n"
-                        myFile.write(CreationDate)
-                    if(elem.attrib.get("LastEditDate") != None):
-                        LastEditDate = t+t+t+t+"<LastEditDate>"+elem.attrib['LastEditDate']+"</LastEditDate> \n"
-                        myFile.write(LastEditDate)
-                    if(elem.attrib.get("LastActivityDate") != None):
-                        LastActivityDate = t+t+t+t+"<LastActivityDate>"+elem.attrib['LastActivityDate']+"</LastActivityDate> \n"
-                        myFile.write(LastActivityDate)
-                    if(elem.attrib.get("CommunityOwnedDate") != None):
-                        CommunityOwnedDate = t+t+t+t+"<CommunityOwnedDate>"+elem.attrib['CommunityOwnedDate']+"</CommunityOwnedDate> \n"
-                        myFile.write(CommunityOwnedDate)
-                    if(elem.attrib.get("ClosedDate") != None):
-                        ClosedDate = t+t+t+t+"<ClosedDate>"+elem.attrib['ClosedDate']+"</ClosedDate> \n"
-                        myFile.write(ClosedDate)
-                    TimeStamp = t+t+t+"</TimeStamp>\n "
-                    myFile.write(TimeStamp)
+                    qaConverter.__write_timestamp(myFile, elem)
         
         
                     '''
@@ -231,25 +220,7 @@ class qaConverter(object):
                     Timestamp information
                     '''
                 
-                    TimeStamp = t+t+t+"<TimeStamp>\n "
-                    myFile.write(TimeStamp)
-                    if(elem.attrib.get("CreationDate") != None):
-                        CreationDate = t+t+t+t+"<CreationDate>"+elem.attrib['CreationDate']+"</CreationDate> \n"
-                        myFile.write(CreationDate)
-                    if(elem.attrib.get("LastEditDate") != None):
-                        LastEditDate = t+t+t+t+"<LastEditDate>"+elem.attrib['LastEditDate']+"</LastEditDate> \n"
-                        myFile.write(LastEditDate)
-                    if(elem.attrib.get("LastActivityDate") != None):
-                        LastActivityDate = t+t+t+t+"<LastActivityDate>"+elem.attrib['LastActivityDate']+"</LastActivityDate> \n"
-                        myFile.write(LastActivityDate)
-                    if(elem.attrib.get("CommunityOwnedDate") != None):
-                        CommunityOwnedDate = t+t+t+t+"<CommunityOwnedDate>"+elem.attrib['CommunityOwnedDate']+"</CommunityOwnedDate> \n"
-                        myFile.write(CommunityOwnedDate)
-                    if(elem.attrib.get("ClosedDate") != None):
-                        ClosedDate = t+t+t+t+"<ClosedDate>"+elem.attrib['ClosedDate']+"</ClosedDate> \n"
-                        myFile.write(ClosedDate)
-                    TimeStamp = t+t+t+"</TimeStamp>\n "
-                    myFile.write(TimeStamp)
+                    qaConverter.__write_timestamp(myFile, elem)
         
         
                     '''
@@ -350,31 +321,32 @@ class qaConverter(object):
                 if(postType[post_id][0]=='1'):
                     if(postIdBuffer.get(post_id)==None):
                         postIdBuffer[post_id] = 1
-                        qaConverter.writeHistoryData(elem,post_id,postIdBuffer[post_id],HistoryType,postType[post_id],1,name)
+                        # elem,post_id,instanceId,HistoryType,postType,val,name
+                        qaConverter.writeHistoryData(elem=elem, post_id=post_id, instanceId=postIdBuffer[post_id], HistoryType=HistoryType, postType=postType[post_id], val=1, name=name)
                     else:
                         postIdBuffer[post_id]+=1
-                        qaConverter.writeHistoryData(elem,post_id,postIdBuffer[post_id],HistoryType,postType[post_id],2,name)
+                        qaConverter.writeHistoryData(elem=elem, post_id=post_id, instanceId=postIdBuffer[post_id], HistoryType=HistoryType, postType=postType[post_id], val=2, name=name)
                     
                     instanceId+=1
                 elif(postType[post_id][0]=='2'):
                     if(postIdBuffer.get(post_id)==None):
                         if(postIdBuffer.get(postType[post_id][1])!=None):
                             postIdBuffer[postType[post_id][1]] += 1
-                            qaConverter.writeHistoryData(elem,post_id,postIdBuffer[postType[post_id][1]],HistoryType,postType[post_id],1,name)
+                            qaConverter.writeHistoryData(elem=elem,post_id=post_id,instanceId=postIdBuffer[postType[post_id][1]],HistoryType=HistoryType,postType=postType[post_id],val=1,name=name)
                         
                     else:
                         if(postIdBuffer.get(postType[post_id][1])!=None):
                             postIdBuffer[postType[post_id][1]]+=1
-                            qaConverter.writeHistoryData(elem,post_id,postIdBuffer[postType[post_id][1]],HistoryType,postType[post_id],2,name)
+                            qaConverter.writeHistoryData(elem=elem,post_id=post_id,instanceId=postIdBuffer[postType[post_id][1]],HistoryType=HistoryType,postType=postType[post_id],val=2,name=name)
                     instanceId+=1
                     
                 else:
                     if(postIdBuffer.get(post_id)==None):
                         postIdBuffer[post_id] = 1
-                        qaConverter.writeHistoryData(elem,post_id,postIdBuffer[post_id],HistoryType,postType[post_id],1,name)
+                        qaConverter.writeHistoryData(elem=elem,post_id=post_id,instanceId=postIdBuffer[post_id],HistoryType=HistoryType,postType=postType[post_id],val=1,name=name)
                     else:
                         postIdBuffer[post_id]+=1
-                        qaConverter.writeHistoryData(elem,post_id,postIdBuffer[post_id],HistoryType,postType[post_id],2,name)
+                        qaConverter.writeHistoryData(elem=elem,post_id=post_id,instanceId=postIdBuffer[post_id],HistoryType=HistoryType,postType=postType[post_id],val=2,name=name)
                     
                     instanceId+=1                    
 
@@ -393,16 +365,145 @@ class qaConverter(object):
         '''
         return postType
         
+    @staticmethod
+    def write_body_rep(elem, myFile):
+        '''
+        Contributors information
+        '''
+        
+        t = '\t'
+        Contributors = t+t+t+"<Contributors>\n"
+        myFile.write(Contributors)
+        if(elem.attrib.get("OwnerUserId") != None):
+            Contributors =t+t+t+t+"<OwnerUserId>"+elem.attrib['OwnerUserId']+"</OwnerUserId>\n"
+            myFile.write(Contributors)
+
+        if(elem.attrib.get("LastEditorUserId") != None):
+            Contributors =t+t+t+t+"<LastEditorUserId>"+elem.attrib['LastEditorUserId']+"</LastEditorUserId>\n"
+            myFile.write(Contributors)
+        Contributors = t+t+t+"</Contributors>\n"
+        myFile.write(Contributors)
 
 
+        '''
+        PostHistory might have a comment associated with each entry.
+        I have added that section as editDetails
+        
+
+        Edit = t+t+t+"<EditDetails>\n"
+        myFile.write(Edit)
+        
+        if(HistoryType.get(int(elem.attrib['PostHistoryTypeId']))!=None):
+            EditType = t+t+t+t+"<EditType>"+HistoryType[int(elem.attrib['PostHistoryTypeId'])]+"</EditType>\n"
+        else:
+            EditType = t+t+t+t+"<EditType>Unknown</EditType>\n"
+        myFile.write(EditType)
+
+        if(elem.attrib.get('Comment')!=None):
+            text_body = textwrap.indent(text=elem.attrib['Comment'], prefix=t+t+t+t)
+            text_body = html.escape(text_body)
+            Body_text = text_body+"\n"
+            EditType = t+t+t+t+"<EditComment>"+Body_text+"</EditComment>\n"
+            myFile.write(EditType)
+        Edit = t+t+t+"</EditDetails>\n"
+        myFile.write(Edit)
+        '''
+        
+
+        '''
+        Writing the body/text part
+        '''
+        if(elem.attrib.get('Body')!=None):        
+            Body = t+t+t+"<Body>\n"
+            myFile.write(Body)
+            text_field = t+t+t+t+"<Text Type= "+'"'+"text"+'"'+" Bytes="+'"'+str(len(elem.attrib['Body']))+'">\n'
+            myFile.write(text_field)
+
+            body_text = elem.attrib['Body']
+            #body_text = self.tag_remover(body_text)
+            text_body = html.escape(body_text)
+            text_body = textwrap.indent(text=text_body, prefix=t+t+t+t+t)
+            
+
+            Body_text = text_body+"\n"
+            myFile.write(Body_text)
+            text_field = t+t+t+t+"</Text>\n"
+            myFile.write(text_field)        
+            Body = t+t+t+"</Body>\n"
+            myFile.write(Body)
+
+        
+        if(elem.attrib.get('Tags')!=None):
+            Tags_element = t+t+t+"<Tags>"+html.escape(elem.attrib['Tags'])+"</Tags>\n"
+            
+            myFile.write(Tags_element)
+        
+        Reputation_tag = t+t+t+"<Credit> \n"
+        myFile.write(Reputation_tag)
+        if(elem.attrib.get("Score") != None):
+            score = t+t+t+t+"<Score>"+elem.attrib['Score']+"</Score>\n"
+            myFile.write(score)
+        if(elem.attrib.get("ViewCount") != None):
+            ViewCount = t+t+t+t+"<ViewCount>"+elem.attrib['ViewCount']+"</ViewCount>\n"
+            myFile.write(ViewCount)
+        if(elem.attrib.get("AnswerCount") != None):        
+            AnswerCount = t+t+t+t+"<AnswerCount>"+elem.attrib['AnswerCount']+"</AnswerCount>\n"
+            myFile.write(AnswerCount)
+        if(elem.attrib.get("CommentCount") != None):
+            CommentCount = t+t+t+t+"<CommentCount>"+elem.attrib['CommentCount']+"</CommentCount>\n"
+            myFile.write(CommentCount)
+    
+        if(elem.attrib.get("FavouriteCount") != None):
+            FavouriteCount = t+t+t+t+"<FavouriteCount>"+elem.attrib['FavouriteCount']+"</FavouriteCount>\n"
+            myFile.write(FavouriteCount)
+    
+        Reputation_tag = t+t+t+"</Credit> \n"
+        myFile.write(Reputation_tag)        
+
+        
+        Instance = t+t+"</Instance>\n"
+        myFile.write(Instance)
 
 
     '''
     Writing the data for posts
     '''
-
     @staticmethod
-    def writePostData(elem,post_id,instanceId,postType,val,name):
+    def __write_timestamp(myFile, elem):
+        t = '\t'
+        '''
+        Timestamp information
+        '''
+    
+        TimeStamp = t+t+t+"<TimeStamp>\n "
+        myFile.write(TimeStamp)
+        if(elem.attrib.get("CreationDate") != None):
+            CreationDate = t+t+t+t+"<CreationDate>"+elem.attrib['CreationDate']+"</CreationDate> \n"
+            myFile.write(CreationDate)
+        if(elem.attrib.get("LastEditDate") != None):
+            LastEditDate = t+t+t+t+"<LastEditDate>"+elem.attrib['LastEditDate']+"</LastEditDate> \n"
+            myFile.write(LastEditDate)
+        if(elem.attrib.get("LastActivityDate") != None):
+            LastActivityDate = t+t+t+t+"<LastActivityDate>"+elem.attrib['LastActivityDate']+"</LastActivityDate> \n"
+            myFile.write(LastActivityDate)
+        if(elem.attrib.get("CommunityOwnedDate") != None):
+            CommunityOwnedDate = t+t+t+t+"<CommunityOwnedDate>"+elem.attrib['CommunityOwnedDate']+"</CommunityOwnedDate> \n"
+            myFile.write(CommunityOwnedDate)
+        if(elem.attrib.get("ClosedDate") != None):
+            ClosedDate = t+t+t+t+"<ClosedDate>"+elem.attrib['ClosedDate']+"</ClosedDate> \n"
+            myFile.write(ClosedDate)
+        TimeStamp = t+t+t+"</TimeStamp>\n "
+        myFile.write(TimeStamp)
+        
+    @staticmethod
+    def writePostData(*args, **kwargs):
+        # elem,post_id,instanceId,postType,val,name
+        elem = kwargs['elem']
+        post_id = kwargs['post_id']
+        instanceId = kwargs['instanceId']
+        postType = kwargs['postType']
+        val = kwargs['val']
+        name = kwargs['name']
         filePath = name+'/'
         if(val==1 and postType[0]!='2'):
             filePath = filePath+"Post"+str(post_id)+".knolml"
@@ -429,128 +530,10 @@ class qaConverter(object):
                 
                 if(f2==1):
         
-                    '''
-                    Timestamp information
-                    '''
-                
-                    TimeStamp = t+t+t+"<TimeStamp>\n "
-                    myFile.write(TimeStamp)
-                    if(elem.attrib.get("CreationDate") != None):
-                        CreationDate = t+t+t+t+"<CreationDate>"+elem.attrib['CreationDate']+"</CreationDate> \n"
-                        myFile.write(CreationDate)
-                    if(elem.attrib.get("LastEditDate") != None):
-                        LastEditDate = t+t+t+t+"<LastEditDate>"+elem.attrib['LastEditDate']+"</LastEditDate> \n"
-                        myFile.write(LastEditDate)
-                    if(elem.attrib.get("LastActivityDate") != None):
-                        LastActivityDate = t+t+t+t+"<LastActivityDate>"+elem.attrib['LastActivityDate']+"</LastActivityDate> \n"
-                        myFile.write(LastActivityDate)
-                    if(elem.attrib.get("CommunityOwnedDate") != None):
-                        CommunityOwnedDate = t+t+t+t+"<CommunityOwnedDate>"+elem.attrib['CommunityOwnedDate']+"</CommunityOwnedDate> \n"
-                        myFile.write(CommunityOwnedDate)
-                    if(elem.attrib.get("ClosedDate") != None):
-                        ClosedDate = t+t+t+t+"<ClosedDate>"+elem.attrib['ClosedDate']+"</ClosedDate> \n"
-                        myFile.write(ClosedDate)
-                    TimeStamp = t+t+t+"</TimeStamp>\n "
-                    myFile.write(TimeStamp)
+                    qaConverter.__write_timestamp(myFile, elem)
         
-        
-                    '''
-                    Contributors information
-                    '''
                     
-                    
-                    Contributors = t+t+t+"<Contributors>\n"
-                    myFile.write(Contributors)
-                    if(elem.attrib.get("OwnerUserId") != None):
-                        Contributors =t+t+t+t+"<OwnerUserId>"+elem.attrib['OwnerUserId']+"</OwnerUserId>\n"
-                        myFile.write(Contributors)
-
-                    if(elem.attrib.get("LastEditorUserId") != None):
-                        Contributors =t+t+t+t+"<LastEditorUserId>"+elem.attrib['LastEditorUserId']+"</LastEditorUserId>\n"
-                        myFile.write(Contributors)
-                    Contributors = t+t+t+"</Contributors>\n"
-                    myFile.write(Contributors)
-
-
-                    '''
-                    PostHistory might have a comment associated with each entry.
-                    I have added that section as editDetails
-                    
-        
-                    Edit = t+t+t+"<EditDetails>\n"
-                    myFile.write(Edit)
-                    
-                    if(HistoryType.get(int(elem.attrib['PostHistoryTypeId']))!=None):
-                        EditType = t+t+t+t+"<EditType>"+HistoryType[int(elem.attrib['PostHistoryTypeId'])]+"</EditType>\n"
-                    else:
-                        EditType = t+t+t+t+"<EditType>Unknown</EditType>\n"
-                    myFile.write(EditType)
-        
-                    if(elem.attrib.get('Comment')!=None):
-                        text_body = textwrap.indent(text=elem.attrib['Comment'], prefix=t+t+t+t)
-                        text_body = html.escape(text_body)
-                        Body_text = text_body+"\n"
-                        EditType = t+t+t+t+"<EditComment>"+Body_text+"</EditComment>\n"
-                        myFile.write(EditType)
-                    Edit = t+t+t+"</EditDetails>\n"
-                    myFile.write(Edit)
-                    '''
-                    
-        
-                    '''
-                    Writing the body/text part
-                    '''
-                    if(elem.attrib.get('Body')!=None):        
-                        Body = t+t+t+"<Body>\n"
-                        myFile.write(Body)
-                        text_field = t+t+t+t+"<Text Type= "+'"'+"text"+'"'+" Bytes="+'"'+str(len(elem.attrib['Body']))+'">\n'
-                        myFile.write(text_field)
-            
-                        body_text = elem.attrib['Body']
-                        #body_text = self.tag_remover(body_text)
-                        text_body = html.escape(body_text)
-                        text_body = textwrap.indent(text=text_body, prefix=t+t+t+t+t)
-                        
-
-                        Body_text = text_body+"\n"
-                        myFile.write(Body_text)
-                        text_field = t+t+t+t+"</Text>\n"
-                        myFile.write(text_field)        
-                        Body = t+t+t+"</Body>\n"
-                        myFile.write(Body)
-
-                    
-                    if(elem.attrib.get('Tags')!=None):
-                        Tags_element = t+t+t+"<Tags>"+html.escape(elem.attrib['Tags'])+"</Tags>\n"
-                        
-                        myFile.write(Tags_element)
-                    
-                    Reputation_tag = t+t+t+"<Credit> \n"
-                    myFile.write(Reputation_tag)
-                    if(elem.attrib.get("Score") != None):
-                        score = t+t+t+t+"<Score>"+elem.attrib['Score']+"</Score>\n"
-                        myFile.write(score)
-                    if(elem.attrib.get("ViewCount") != None):
-                        ViewCount = t+t+t+t+"<ViewCount>"+elem.attrib['ViewCount']+"</ViewCount>\n"
-                        myFile.write(ViewCount)
-                    if(elem.attrib.get("AnswerCount") != None):        
-                        AnswerCount = t+t+t+t+"<AnswerCount>"+elem.attrib['AnswerCount']+"</AnswerCount>\n"
-                        myFile.write(AnswerCount)
-                    if(elem.attrib.get("CommentCount") != None):
-                        CommentCount = t+t+t+t+"<CommentCount>"+elem.attrib['CommentCount']+"</CommentCount>\n"
-                        myFile.write(CommentCount)
-                
-                    if(elem.attrib.get("FavouriteCount") != None):
-                        FavouriteCount = t+t+t+t+"<FavouriteCount>"+elem.attrib['FavouriteCount']+"</FavouriteCount>\n"
-                        myFile.write(FavouriteCount)
-                
-                    Reputation_tag = t+t+t+"</Credit> \n"
-                    myFile.write(Reputation_tag)        
-
-                    
-                    Instance = t+t+"</Instance>\n"
-                    myFile.write(Instance)
-                     
+                    qaConverter.write_body_rep(elem,myFile)
                     
         
         else:
@@ -579,127 +562,9 @@ class qaConverter(object):
                     Timestamp information
                     '''
                 
-                    TimeStamp = t+t+t+"<TimeStamp>\n "
-                    myFile.write(TimeStamp)
-                    if(elem.attrib.get("CreationDate") != None):
-                        CreationDate = t+t+t+t+"<CreationDate>"+elem.attrib['CreationDate']+"</CreationDate> \n"
-                        myFile.write(CreationDate)
-                    if(elem.attrib.get("LastEditDate") != None):
-                        LastEditDate = t+t+t+t+"<LastEditDate>"+elem.attrib['LastEditDate']+"</LastEditDate> \n"
-                        myFile.write(LastEditDate)
-                    if(elem.attrib.get("LastActivityDate") != None):
-                        LastActivityDate = t+t+t+t+"<LastActivityDate>"+elem.attrib['LastActivityDate']+"</LastActivityDate> \n"
-                        myFile.write(LastActivityDate)
-                    if(elem.attrib.get("CommunityOwnedDate") != None):
-                        CommunityOwnedDate = t+t+t+t+"<CommunityOwnedDate>"+elem.attrib['CommunityOwnedDate']+"</CommunityOwnedDate> \n"
-                        myFile.write(CommunityOwnedDate)
-                    if(elem.attrib.get("ClosedDate") != None):
-                        ClosedDate = t+t+t+t+"<ClosedDate>"+elem.attrib['ClosedDate']+"</ClosedDate> \n"
-                        myFile.write(ClosedDate)
-                    TimeStamp = t+t+t+"</TimeStamp>\n "
-                    myFile.write(TimeStamp)
+                    qaConverter.__write_timestamp(myFile, elem)
         
-        
-                    '''
-                    Contributors information
-                    '''
-                    
-                    
-    
-                    Contributors = t+t+t+"<Contributors>\n"
-                    myFile.write(Contributors)
-                    if(elem.attrib.get("OwnerUserId") != None):
-                        Contributors =t+t+t+t+"<OwnerUserId>"+elem.attrib['OwnerUserId']+"</OwnerUserId>\n"
-                        myFile.write(Contributors)
-
-                    if(elem.attrib.get("LastEditorUserId") != None):
-                        Contributors =t+t+t+t+"<LastEditorUserId>"+elem.attrib['LastEditorUserId']+"</LastEditorUserId>\n"
-                        myFile.write(Contributors)
-                    Contributors = t+t+t+"</Contributors>\n"
-                    myFile.write(Contributors)
-                    
-        
-                    '''
-                    Writing the body/text part
-                    '''
-                    if(elem.attrib.get('Body')!=None):        
-                        Body = t+t+t+"<Body>\n"
-                        myFile.write(Body)
-                        text_field = t+t+t+t+"<Text Type= "+'"'+"text"+'"'+" Bytes="+'"'+str(len(elem.attrib['Body']))+'">\n'
-                        myFile.write(text_field)
-            
-                        body_text = elem.attrib['Body']
-                        #body_text = self.tag_remover(body_text)
-                        text_body = html.escape(body_text)
-                        text_body = textwrap.indent(text=text_body, prefix=t+t+t+t+t)
-                        
-
-                        Body_text = text_body+"\n"
-                        myFile.write(Body_text)
-                        text_field = t+t+t+t+"</Text>\n"
-                        myFile.write(text_field)        
-                        Body = t+t+t+"</Body>\n"
-                        myFile.write(Body)
-
-
-                    if(elem.attrib.get('Tags')!=None):
-                        Tags_element = t+t+t+"<Tags>"+html.escape(elem.attrib['Tags'])+"</Tags>\n"
-                        
-                        myFile.write(Tags_element)
-                    
-                    Reputation_tag = t+t+t+"<Credit> \n"
-                    myFile.write(Reputation_tag)
-                    if(elem.attrib.get("Score") != None):
-                        score = t+t+t+t+"<Score>"+elem.attrib['Score']+"</Score>\n"
-                        myFile.write(score)
-                    if(elem.attrib.get("ViewCount") != None):
-                        ViewCount = t+t+t+t+"<ViewCount>"+elem.attrib['ViewCount']+"</ViewCount>\n"
-                        myFile.write(ViewCount)
-                    if(elem.attrib.get("AnswerCount") != None):        
-                        AnswerCount = t+t+t+t+"<AnswerCount>"+elem.attrib['AnswerCount']+"</AnswerCount>\n"
-                        myFile.write(AnswerCount)
-                    if(elem.attrib.get("CommentCount") != None):
-                        CommentCount = t+t+t+t+"<CommentCount>"+elem.attrib['CommentCount']+"</CommentCount>\n"
-                        myFile.write(CommentCount)
-                
-                    if(elem.attrib.get("FavouriteCount") != None):
-                        FavouriteCount = t+t+t+t+"<FavouriteCount>"+elem.attrib['FavouriteCount']+"</FavouriteCount>\n"
-                        myFile.write(FavouriteCount)
-                
-                    Reputation_tag = t+t+t+"</Credit> \n"
-                    myFile.write(Reputation_tag)        
-
-        
-                    '''
-                    PostHistory might have a comment associated with each entry.
-                    I have added that section as editDetails
-                    
-        
-                    Edit = t+t+t+"<EditDetails>\n"
-                    myFile.write(Edit)
-                    
-                    if(HistoryType.get(int(elem.attrib['PostHistoryTypeId']))!=None):
-                        EditType = t+t+t+t+"<EditType>"+HistoryType[int(elem.attrib['PostHistoryTypeId'])]+"</EditType>\n"
-                    else:
-                        EditType = t+t+t+t+"<EditType>Unknown</EditType>\n"
-                    myFile.write(EditType)
-        
-                    if(elem.attrib.get('Comment')!=None):
-                        text_body = textwrap.indent(text=elem.attrib['Comment'], prefix=t+t+t+t+t)
-                        text_body = html.escape(text_body)
-                        Body_text = text_body+"\n"
-                        EditType = t+t+t+t+"<EditComment>\n"
-                        myFile.write(EditType)
-                        myFile.write(Body_text)
-                        EditType = t+t+t+t+"</EditComment>\n"
-                        myFile.write(EditType)
-                    Edit = t+t+t+"</EditDetails>\n"
-                    myFile.write(Edit)
-                    '''
-    
-                    Instance = t+t+"</Instance>\n"
-                    myFile.write(Instance)
-
+                    qaConverter.write_body_rep(elem,myFile)
 
 
 
@@ -733,11 +598,12 @@ class qaConverter(object):
                     postType = [elem.attrib['PostTypeId']]
                     if(postIdBuffer.get(post_id)==None):
                         postIdBuffer[post_id] = 1
-                        qaConverter.writePostData(elem,post_id,postIdBuffer[post_id],postType,1,name)
+                        #elem,post_id,instanceId,postType,val,name
+                        qaConverter.writePostData(elem=elem,post_id=post_id,instanceId=postIdBuffer[post_id],postType=postType,val=1,name=name)
                     else:
                         
                         postIdBuffer[post_id]+=1
-                        qaConverter.writePostData(elem,post_id,postIdBuffer[post_id],postType,2,name)
+                        qaConverter.writePostData(elem=elem,post_id=post_id,instanceId=postIdBuffer[post_id],postType=postType,val=2,name=name)
                     
                     instanceId+=1
                 elif(elem.attrib['PostTypeId']=='2'):
@@ -745,23 +611,23 @@ class qaConverter(object):
                     if(postIdBuffer.get(post_id)==None):
                         if(postIdBuffer.get(postType[1])!=None):
                             postIdBuffer[postType[1]] += 1
-                            qaConverter.writePostData(elem,post_id,postIdBuffer[postType[1]],postType,1,name)
+                            qaConverter.writePostData(elem=elem,post_id=post_id,instanceId=postIdBuffer[postType[1]],postType=postType,val=1,name=name)
                         
                     else:
                         if(postIdBuffer.get(postType[1])!=None):
                             postIdBuffer[postType[1]] += 1
-                            qaConverter.writePostData(elem,post_id,postIdBuffer[postType[1]],postType,2,name)
+                            qaConverter.writePostData(elem=elem,post_id=post_id,instanceId=postIdBuffer[postType[1]],postType=postType,val=2,name=name)
                     instanceId+=1
                     
                 else:
                     postType = [elem.attrib['PostTypeId']]
                     if(postIdBuffer.get(post_id)==None):
                         postIdBuffer[post_id] = 1
-                        qaConverter.writePostData(elem,post_id,postIdBuffer[post_id],postType,1,name)
+                        qaConverter.writePostData(elem=elem,post_id=post_id,instanceId=postIdBuffer[post_id],postType=postType,val=1,name=name)
                     else:
                         
                         postIdBuffer[post_id]+=1
-                        qaConverter.writePostData(elem,post_id,postIdBuffer[post_id],postType,2,name)
+                        qaConverter.writePostData(elem=elem,post_id=post_id,instanceId=postIdBuffer[post_id],postType=postType,val=2,name=name)
                     
                     instanceId+=1
                     
@@ -1062,7 +928,8 @@ class qaConverter(object):
                 
     
     @staticmethod            
-    def convert(name, *args, **kwargs):
+    def convert(*args, **kwargs):
+        name = kwargs['name']
         name = name.lower()
         if(kwargs.get('download')!=None):             
             down = kwargs['download']
